import { useEffect, useState } from "react";
import { checkPermissions } from "../../check-permissions.js";
import { App } from "@capacitor/app"; // Make sure to import the App from capacitor.
import { emitter } from "../../emitter.js";
import { packageLog } from "../../package-log.js";
export function usePermissionsStatus() {
    const log = packageLog.extend(usePermissionsStatus.name);
    const [permissionsStatus, setPermissionsStatus] = useState(undefined);
    const [isLoading, setIsLoading] = useState(true);
    async function updatePermissionsStatus() {
        const permissionsStatus = await checkPermissions();
        setPermissionsStatus(permissionsStatus);
        setIsLoading(false);
    }
    useEffect(() => {
        updatePermissionsStatus();
        const resumeListener = App.addListener("resume", updatePermissionsStatus);
        const permissionsChangedListener = emitter.on("permissionsChanged", (permissionsStatus) => {
            log(`permissionsChanged event received`, permissionsStatus);
            setPermissionsStatus(permissionsStatus);
        });
        return () => {
            resumeListener.then((resumeListener) => resumeListener.remove());
            emitter.off("permissionsChanged", permissionsChangedListener);
        };
    }, []);
    return {
        permissionsStatus,
        isLoading,
        updatePermissionsStatus,
    };
}
