import { Geolocation } from "@capacitor/geolocation";
import { packageLog } from "./package-log.js";
export async function watchPosition(options) {
    const log = packageLog.extend(watchPosition.name);
    log({ options });
    const { containerLinkId, watchPositionOptions = {} } = options;
    return await Geolocation.watchPosition(watchPositionOptions, async (position, error) => {
        const callbackLog = log.extend("callback");
        callbackLog({ position, error });
        if (error) {
            throw error;
        }
        const { data: [positionLinkFromSelect], } = await this.select({
            type_id: this.capacitorGeolocationPackage.Position.idLocal(),
            in: {
                type_id: {
                    _id: ["@deep-foundation/core", "Contain"],
                },
                from_id: containerLinkId,
            },
        });
        callbackLog({ positionLinkFromSelect });
        if (positionLinkFromSelect) {
            await this.updatePosition({
                position,
                id: positionLinkFromSelect.id,
            });
            return;
        }
        else {
            await this.insertPosition({ position, containerLinkId });
        }
    });
}
